<?php

namespace Ardent\PipelineBundle\Pipeline\OptionsProcessor;

use Exception;
use Psr\Container\ContainerInterface;

class OptionsStageBag implements ContainerInterface
{
    /**
     * @var OptionsStageInterface[]
     */
    private array $stages = [];

    public function __construct(
        iterable $optionProcessors
    )
    {
        foreach ($optionProcessors as $optionProcessor) {
            /** @var OptionsStageInterface $optionProcessor */
            $this->stages[get_class($optionProcessor)] = $optionProcessor;
        }
    }

    /**
     * @template T of OptionsStageInterface
     * @param class-string<T> $id
     * @return T
     */
    public function get(string $id): OptionsStageInterface
    {
        if (!$this->has($id)) {
            throw new Exception(sprintf('Class "%s" in not an OptionsStageInterface, it is not in the OptionsStageBag', $id));
        }

        return $this->stages[$id];
    }

    public function has(string $id): bool
    {
        return array_key_exists($id, $this->stages);
    }
}